@@ -23,6 +23,7 @@
 #include "gda-corba.h"
 #include "gda-connection.h"
 #include "gda-command.h"
+#include <bonobo.h>
 
 #include <gtk/gtksignal.h>
 
@@ -135,7 +136,7 @@ gda_connection_class_init (GdaConnectionClass * klass)
 	gtk_object_class_add_signals (object_class, gda_connection_signals,
 				      LAST_SIGNAL);
 
-	object_class->destroy = gda_connection_destroy;
+	object_class->destroy = (void (*)(GtkObject *))gda_connection_destroy;
 	klass->error = gda_connection_real_error;
 	klass->warning = gda_connection_real_warning;
 	klass->close = NULL;
@@ -456,8 +457,8 @@ gda_connection_open (GdaConnection * cnc, const gchar * dsn,
 	}
 
 	cnc->database = g_strdup (db_to_use);
-	cnc->user = g_strdup (user);
-	cnc->passwd = g_strdup (pwd);
+	cnc->user = user ? g_strdup (user) : g_strdup ("");
+	cnc->passwd = pwd ? g_strdup (pwd) : g_strdup ("");
 
 	/* start CORBA connection */
 	if (get_corba_connection (cnc) < 0) {
